@@ -2,12 +2,11 @@ package Class::Usul::TraitFor::UntaintedGetopts;
 
 use namespace::autoclean;
 
-use Class::Usul::Constants qw( FAILED NUL );
+use Class::Usul::Constants qw( FAILED NUL TRUE );
 use Class::Usul::Functions qw( untaint_cmdline );
+use Class::Usul::Getopt    qw( describe_options );
 use Data::Record;
 use Encode                 qw( decode );
-use Getopt::Long 2.38;
-use Getopt::Long::Descriptive 0.091;
 use JSON::MaybeXS          qw( decode_json );
 use Regexp::Common;
 use Scalar::Util           qw( blessed );
@@ -57,6 +56,10 @@ my $_option_specification = sub {
    return $option_spec;
 };
 
+my $_set_usage_conf = sub {
+   return Class::Usul::Getopt::Usage->usage_conf( $_[ 0 ] );
+};
+
 my $_split_args = sub {
    my $splitters = shift; my @new_argv;
 
@@ -126,15 +129,16 @@ my $_parse_options = sub {
 
    my ($splitters, @options) = $_build_options->( \%data );
 
-   my @flavour; defined $config{flavour}
-      and push @flavour, { getopt_conf => $config{flavour} };
+   my %gld_conf; my @gld_attr = ('getopt_conf', 'show_defaults');
 
-   $config{protect_argv} and local @ARGV = @ARGV;
+   @gld_conf{ @gld_attr } = @config{ @gld_attr };
+   $config{usage_conf   } and $_set_usage_conf->( $config{usage_conf} );
+   $config{protect_argv } and local @ARGV = @ARGV;
    $enc and @ARGV = map { decode( $enc, $_ ) } @ARGV;
    $config{no_untaint} or @ARGV = map { untaint_cmdline $_ } @ARGV;
    $Untainted_Argv = [ @ARGV ];
    keys %{ $splitters } and @ARGV = $_split_args->( $splitters );
-   ($opt, $Usage) = describe_options( ('Usage: %c %o'), @options, @flavour );
+   ($opt, $Usage) = describe_options( 'Usage: %c %o', @options, \%gld_conf );
    $Extra_Argv = [ @ARGV ];
 
    my ($params, @missing)
